@@ -1,8 +1,8 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "erlang" "28.3"
+(define-package "erlang" "28.3.1"
   "Major modes for editing and running Erlang."
   '((emacs "24.3"))
   :url "https://github.com/erlang/otp"
-  :commit "ab489c0b260c637a9487f8753909ea94dacbbec2"
-  :revdesc "OTP-28.3-0-gab489c0b260c"
+  :commit "aa5b1d3366762ff8f420f2aa6a52604b481530c9"
+  :revdesc "OTP-28.3.1-0-gaa5b1d336676"
   :keywords '("erlang" "languages" "processes"))
